@@ -7,7 +7,8 @@ test_that('vars.varored works for Canada', {
   d.vselect <- vars::VARselect(Canada, lag.max = 5, type = 'const')$selection[1]
   d.var <- vars::VAR(Canada, p = d.vselect, type = 'const')
 
-  fortified <- ggplot2::fortify(stats::predict(d.var, n.ahead = 50))
+  d.predicted <- stats::predict(d.var, n.ahead = 50)
+  fortified <- ggplot2::fortify(d.predicted)
   expect_equal(is.data.frame(fortified), TRUE)
   expect_equal(nrow(fortified), 50 + nrow(Canada))
 
@@ -20,7 +21,13 @@ test_that('vars.varored works for Canada', {
   expect_equal(fortified$Index[1], as.Date('1980-01-01'))
   expect_equal(fortified$Index[nrow(fortified)], as.Date('2013-04-01'))
 
-  fortified <- ggplot2::fortify(stats::predict(d.var, n.ahead = 50), melt = TRUE)
+  p <- ggplot2::autoplot(d.predicted)
+  expect_true(is(p, 'ggplot'))
+
+  p <- ggplot2::autoplot(d.predicted, ts.connect = FALSE)
+  expect_true(is(p, 'ggplot'))
+
+  fortified <- ggplot2::fortify(d.predicted, melt = TRUE)
   expect_equal(is.data.frame(fortified), TRUE)
   expect_equal(nrow(fortified), (50 + nrow(Canada)) * 4)
 
